#
# spec file for package VFlib3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libVFlib3-10
Name:           VFlib3
Version:        3.7.2
Release:        3.3
Summary:        Versatile Font Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Summary(ja):    "Versatile" フォントライブラリ
URL:            http://www-masu.ist.osaka-u.ac.jp/~kakugawa/VFlib/
Source0:        http://www-masu.ist.osaka-u.ac.jp/~kakugawa/download/TypeHack/VFlib3-%{version}.tar.gz
Patch1:         VFlib3-add-external.patch
Patch2:         VFlib3-freetype2-fix.patch
Patch3:         VFlib3-gcc14-fixes.patch
Source1:        vflibcap-tex
BuildRequires:  fdupes
BuildRequires:  imake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(kpathsea)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
Requires(post): %{install_info_prereq}
Requires(postun):%{install_info_prereq}

%description -l ja
VFlib は C 言語で書かれたフォントライブラリで、指定したフォン
トのビットマップを得るための関数群を持っています。VFlib の特徴は、
さまざまなフォーマットのフォントをフォーマットの違いを気にする
ことなく統一的に使うことができるところにあります。

VFlib では、以下のフォントフォーマットがサポートされています。
     TeX 関連:       PK, GF, VF, TFM
     Omega TeX 関連: OFM (レベル 0),OVF
     X Window 関連:  PCF, BDF

%description
VFlib is a font library written in C language with several functions to
obtain bitmaps of fonts. A unique feature of VFlib is that fonts in
different formats are accessed by unified interface.

VFlib supports the following font formats:
* TeX fonts: PK, GF, VF, TFM Omega
* TeX fonts: OFM (level 0), OVF
* X Window fonts: PCF, BDF.
* Other fonts: TrueType, Type 1, HBF, Syotai Club, JG, ekanji

%package -n %{libname}
Summary:        Versatile font library VFlib3
Group:          System/Libraries

%description -n %{libname}
VFlib is a font library written in C language with several functions to
obtain bitmaps of fonts. A unique feature of VFlib is that fonts in
different formats are accessed by unified interface.

VFlib supports the following font formats:
* TeX fonts: PK, GF, VF, TFM Omega
* TeX fonts: OFM (level 0), OVF
* X Window fonts: PCF, BDF.
* Other fonts: TrueType, Type 1, HBF, Syotai Club, JG, ekanji

%package -n VFlib3-devel
Summary:        Development libraries for VFlib3
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(kpathsea)

%description -n VFlib3-devel
Development headers and libraries for VFlib3

%prep
%autosetup -p1

%build
%configure \
            --with-kpathsea \
            --with-opentype \
            --with-texmf-root=%{_datadir}/texmf \
            --with-gettext
make %{?_smp_mflags}

%install
make prefix=%{buildroot}%{_prefix} \
     infodir=%{buildroot}%{_infodir} \
     mandir=%{buildroot}%{_mandir} \
     includedir=%{buildroot}%{_includedir} \
     libdir=%{buildroot}%{_libdir} \
     bindir=%{buildroot}%{_bindir} \
     datadir=%{buildroot}%{_datadir} \
     runtimedir=%{buildroot}%{_datadir}/VFlib/%{version} \
     install
install -m 644 %{SOURCE1} %{buildroot}%{_datadir}/VFlib/%{version}/
# remove duped docs
rm -rf %{buildroot}%{_datadir}/VFlib/%{version}/doc/
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -type f -name "*.a" -delete -print

%fdupes %{buildroot}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/VFlib-36.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/VFlib-36.info%{ext_info}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc ANNOUNCE* CHANGES DISTRIB*
%license LICENSE-FTL.TXT LICENSE-GPLV3.TXT
%{_infodir}/VFlib*info*
%dir %{_datadir}/VFlib
%dir %{_datadir}/VFlib/%{version}
%dir %{_datadir}/VFlib/%{version}/t1lib/
%{_datadir}/VFlib/%{version}/t1lib/*
%dir %{_datadir}/VFlib/%{version}/ccv/
%{_datadir}/VFlib/%{version}/ccv/*
%dir %{_datadir}/VFlib/%{version}/ascii-jtex/
%{_datadir}/VFlib/%{version}/ascii-jtex/*
%{_datadir}/VFlib/%{version}/vflibcap*
%{_bindir}/*

%files -n %{libname}
%{_libdir}/libVFlib3.so.*

%files -n VFlib3-devel
%{_libdir}/libVFlib3.so
%{_includedir}/*

%changelog
* Fri Aug 23 2024 Takashi Iwai <tiwai@suse.com>
- Fix the build with gcc14:
  VFlib3-freetype2-fix.patch
  VFlib3-gcc14-fixes.patch
* Wed May 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprectated
  %%patchN syntax.
* Thu Feb  4 2021 tiwai@suse.de
- Update to version 3.7.2:
  * Relased under dual-license (GPL v3 and FreeType).
- Dropped obsoleted patches:
  VFlib3-compare-always-false.patch
  VFlib3-freetype2.patch
  VFlib3-gnu_source-declaration.patch
  VFlib3-include.patch
  VFlib3-info-dir.patch
- Fix the build with the recent gcc due to the duplicated symbols:
  VFlib3-add-external.patch
* Mon Jul 24 2017 jengelh@inai.de
- Rectify RPM groups and description typography.
* Thu Jul 20 2017 tchvatal@suse.com
- Switch to configure macro, uncomment japanese descriptions
- Take patches from debian:
  * VFlib3-compare-always-false.patch
  * VFlib3-freetype2.patch
  * VFlib3-gnu_source-declaration.patch
- Remove patches obsoleted by the above:
  * VFlib3-ppc64.patch
  * comparison-is-always-false-due-to-limited-range-of-data-type.patch
- Link against freetype2
- Split library to proper subpackage
- Reduce dependencies to contain only those really needed for build
* Sat Mar 26 2016 i@marguerite.su
- clean specfile
* Fri Sep 13 2013 mvyskocil@suse.com
- don't build with t1lib, no longer in Factory
* Mon Jul  2 2012 i@marguerite.su
- fix openSUSE builds
- fix rpmlint warnings.
* Mon Feb 20 2012 coolo@suse.com
- 12.2 has split freetype-devel
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Apr 26 2007 ro@suse.de
- use texlive for building
* Tue Jan 16 2007 mfabian@suse.de
- update to 3.6.14.
  • Enhanced vflmkcaptex for searching dvips config files.
  • Upgrade to T1Lib 5.1.
- remove VFlib3-3.6.12-missing-headers.patch,
  VFlib3-3.6.12-gcc33.patch (included upstream).
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 22 2005 ro@suse.de
- fix implicit declarations
* Tue Jul 12 2005 mfabian@suse.de
- Bugzilla #95088: add patch by Olaf Hering <olh@suse.de> to
  remove a few compiler warnings on PPC.
- add te_kpath to "Requires:" of VFlib3-devel
* Sun May 23 2004 ro@suse.de
- get rid of some compiler warnings
* Mon Jan 12 2004 ro@suse.de
- removed run_ldconfig
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Sun Jun 15 2003 mfabian@suse.de
- fix "directory not owned by any package".
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb 14 2003 mfabian@suse.de
- update to 3.6.13
- use %%install_info macro (Bug #23389)
- fix info dir
* Thu Jan 23 2003 meissner@suse.de
- Fixed ppc64 libtool problem, fixed gcc 3.3 compile problem.
* Sat Aug 10 2002 mfabian@suse.de
- update to 3.6.12
  * Inproved vflimkcaptex to read mode.cf to obtain device resolution.
  * Bug fix of vflimkcaptex.
  * Fixed memory leaks as possible.
  * Upgrade to T1Lib 1.3.
- VFlib3-devel should require VFlib3
- add directories to files list which didn't belong to any package
* Wed Apr 10 2002 mfabian@suse.de
- use %%{_libdir}
- remove --with-kpathsea-includedir=/usr/include and
  - -with-t1lib-includedir=/usr/include because gcc 3.1 doesn't
  like it.
* Fri Aug 10 2001 mfabian@suse.de
- update to VFlib3-3.6.10
- remove VFlib3-3.6.10-make-missing-glyph.patch (included upstream)
- remove VFlib3-3.6.10-vflibcaps.patch and add a "vflibcap-tex"
  working for pTeX/pLaTeX as an extra source file instead
- prefer pk fonts to Type1 fonts again, Type1 fonts are rendered
  too slow especially the Wadalab fonts for CJK-LaTeX. pk
  fonts are only slow once, when they have to be created. The
  rendering later is fast. On top of that, there is a spacing
  problem with the Wadalab PostScript fonts, they are spaced
  much too wide (this problem was not present in VFlib3-3.6.9).
* Tue Mar  6 2001 mfabian@suse.de
- add "jis" and "jisg" to '((ascii-jtex-kanji "%%f.jtex")'
  font-mapping these fonts are used for example by the
  new Japanese document classes from the jsclasses package.
* Fri Feb 23 2001 mfabian@suse.de
- changes to vflibcap-tex:
  prefer Type1 fonts to pk fonts, add entry for TrueType fonts,
  add option to make missing pk fonts
- fix the creation of missing pk fonts in fsearchc.
* Fri Feb 23 2001 mfabian@suse.de
- added info files to file list
* Fri Feb 16 2001 mfabian@suse.de
- new package: VFlib3 version 3.6.9
